Generic wrapper around ggplot2 layer functions.

xp_geoms(mapping = NULL, xp_theme, name, ggfun, ...)

Arguments

mapping

ggplot2 aesthetics for the target layer.

xp_theme

An `xpose_theme` object.

name

Name of the destination layer for the argument parsing (e.g. point).

ggfun

Name of the ggplot2 layer function to be called.

...

Additional arguments to be parsed and passed to the destination layer.

Value

Output of the `ggfun` call.